Simple test
------------

Ensure your device works with this simple test.

.. literalinclude:: ../examples/htu31d_simpletest.py
    :caption: examples/htu31d_simpletest.py
    :linenos:

Setting Resolution Example
--------------------------

Show how to setup Relative Humidity and Temperature Sensor Resolutions

.. literalinclude:: ../examples/htu31d_setting_resolutions.py
    :caption: examples/htu31d_setting_resolutions.py
    :linenos:
